# Knexpy

<center>
<a href="https://github.com/carlossilva2/Knexpy/blob/main/LICENSE" target="blank"><img src="https://img.shields.io/github/license/carlossilva2/Knexpy?style=round-square&color=green" alt="Knexpy License" /></a>
[![Downloads](https://pepy.tech/badge/knexpy)](https://pepy.tech/project/knexpy)
[![Knexpy](https://img.shields.io/pypi/v/knexpy.svg)](https://pypi.org/project/knexpy)
[![Supported Versions](https://img.shields.io/pypi/pyversions/knexpy.svg)](https://pypi.org/project/knexpy)
[![Documentation Status](https://readthedocs.org/projects/knexpy/badge/?version=latest)](https://knexpy.readthedocs.io/en/latest/?badge=latest)
[![Black](https://img.shields.io/badge/code%20style-black-000000)](https://github.com/psf/black)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Github](https://img.shields.io/badge/GitHub-100000?style=plastic&logo=github&logoColor=white)](https://github.com/carlossilva2/Knexpy)
<a href="https://www.buymeacoffee.com/cmsilva" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/default-orange.png" alt="Buy Me A Coffee" height="23" width="100" style="border-radius:5px" /></a>
</center>

A query builder for SQLite3 based on Knexjs

## Installation

### Via [PyPi](https://pypi.org/project/knexpy)

```bash
pip install knexpy
```

### Via Source

```bash
git clone https://github.com/carlossilva2/Knexpy.git
cd Knexpy
pip install .
```

## Demo

![Demo](https://github.com/carlossilva2/Knexpy/blob/main/static/Demo.gif?raw=true)

Check [PyPi](https://pypi.org/project/knexpy/) for more information.
